@@ -217,7 +217,7 @@ class MmdetDetectionModel(DetectionModel):
 
         # update model image size
         if image_size is not None:
-            self.model.cfg.data.test.pipeline[1]["img_scale"] = (image_size,)
+            self.model.cfg.data.test.pipeline[1]["img_scale"] = (image_size, image_size)
         # perform inference
         prediction_result = inference_detector(self.model, image)
 
@@ -386,6 +386,7 @@ class Yolov5DetectionModel(DetectionModel):
         # set model
         try:
             model = yolov5.load(self.model_path, device=self.device)
+            model.conf = self.confidence_threshold
             self.model = model
         except Exception as e:
             TypeError("model_path is not a valid yolov5 model path: ", e)
